@@ -27,6 +27,7 @@
 //! ```rust
 //! use bitvector_simd::BitVector;
 //!
+//! let _ = BitVector::ones(1_792); //create a set containing 0 ..= 1791
 //! let mut bitvector = BitVector::ones(1_000); //create a set containing 0 ..= 999
 //! bitvector.set(1_999, true); // add 1999 to the set, bitvector will be automatically expanded
 //! bitvector.set(500, false); // delete 500 from the set
@@ -59,7 +60,6 @@
 //!
 //! Benchmarks on author's environment show that it does not outperformance existing bitvector
 //! libraries (too much). It is just OK to use existing ones such like [bit_vec](https://docs.rs/bit-vec/0.6.3/bit_vec/).
-
 use std::{
     fmt::Display,
     ops::{BitAnd, BitOr, BitXor, Index, Not},
@@ -194,7 +194,8 @@ impl BitVector {
         if bytes > 0 || bits > 0 {
             let slice = (0..bytes as u64)
                 .map(|_| u64::MAX)
-                .chain([(u64::MAX >> (u64::BITS - bits as u32) << (u64::BITS - bits as u32))])
+                // bits may be 0, we should use checked_str to avoid panic
+                .chain([(u64::MAX.checked_shr(u64::BITS - bits as u32).unwrap_or(0).checked_shl(u64::BITS - bits as u32).unwrap_or(0))])
                 .chain((0..(512 / u64::BITS) - bytes as u32 - 1).map(|_| 0))
                 .collect::<Vec<_>>();
             assert_eq!(slice.len(), 8);
@@ -585,7 +586,7 @@ impl From<BitVector> for Vec<bool> {
                 let mut slice = [0u64; 8];
                 // Packed SIMD does not provide any API to directly transform x into a slice
                 // x.extract will consume itself which makes remaining data unaccessable.
-                x.write_to_slice_aligned(&mut slice);
+                x.write_to_slice_unaligned(&mut slice);
                 slice
             })
             .flat_map(|x| (0..u64::BITS).map(move |i| (x >> (u64::BITS - i - 1)) & 1 > 0))
@@ -602,7 +603,7 @@ impl From<BitVector> for Vec<usize> {
                 let mut slice = [0u64; 8];
                 // Packed SIMD does not provide any API to directly transform x into a slice
                 // x.extract will consume itself which makes remaining data unaccessable.
-                x.write_to_slice_aligned(&mut slice);
+                x.write_to_slice_unaligned(&mut slice);
                 slice
             })
             .flat_map(|x| (0..u64::BITS).map(move |i| (x >> (u64::BITS - i - 1)) & 1 > 0))
